@@ -1,7 +1,7 @@
 package Log::ger;
 
-our $DATE = '2017-06-26'; # DATE
-our $VERSION = '0.008'; # VERSION
+our $DATE = '2017-06-28'; # DATE
+our $VERSION = '0.009'; # VERSION
 
 #IFUNBUILT
 # # use strict;
@@ -24,6 +24,8 @@ our %Level_Aliases = (
 
 our $Current_Level = 3;
 
+our $Caller_Depth_Offset = 0;
+
 # a flag that can be used by null output to skip using formatter
 our $_logger_is_null;
 
@@ -33,8 +35,6 @@ our %Global_Hooks;
 
 # key = phase, value = [ [key, prio, coderef], ... ]
 our %Default_Hooks = (
-    create_filter => [],
-
     create_formatter => [
         [__PACKAGE__, 90,
          # the default formatter is sprintf-style that dumps data structures
@@ -62,6 +62,8 @@ our %Default_Hooks = (
          }],
     ],
 
+    create_layouter => [],
+
     create_routine_names => [
         [__PACKAGE__, 90,
          # the default names are log_LEVEL() and log_is_LEVEL() for subroutine
@@ -114,8 +116,6 @@ our %Default_Hooks = (
          }],
     ],
 
-    after_create_is_routine => [],
-
     before_install_routines => [],
 
     after_install_routines => [],
@@ -193,17 +193,11 @@ sub init_target {
         init_args  => $init_args,
     );
 
-    my $package;
-    if ($target eq 'package') {
-        $package = $target_arg;
-    }
-
-    my $code_filter = run_hooks(
-        'create_filter', \%hook_args, 1, $target, $target_arg);
-
-    my $code_formatter =
+    my $formatter =
         run_hooks('create_formatter', \%hook_args, 1, $target, $target_arg);
-    die "No hook created formatter routine" unless $code_formatter;
+
+    my $layouter =
+        run_hooks('create_layouter', \%hook_args, 1, $target, $target_arg);
 
     my $routine_names0 =
         run_hooks('create_routine_names', \%hook_args, 1,
@@ -212,6 +206,8 @@ sub init_target {
 
     my @routines;
     my $object = $target eq 'object';
+
+  CREATE_LOGGER:
     {
         my $routine_names = $target eq 'package' ?
             $routine_names0->{log_subs} : $routine_names0->{log_methods};
@@ -223,44 +219,70 @@ sub init_target {
             local $hook_args{str_level} = $lname;
 
             $_logger_is_null = 0;
-            my $code0_log =
+            my $logger0 =
                 run_hooks('create_log_routine', \%hook_args, 1,
                           $target, $target_arg);
-            next unless $code0_log;
-            my $code_log;
-            if ($_logger_is_null) {
-                # we don't need to format null logger
-                $code_log = $code0_log;
-            } elsif ($code_filter) {
-                if ($object) {
-                    $code_log = sub {
-                        return unless $code_filter->($lnum, $init_args);
-                        shift;
-                        my $msg = $code_formatter->(@_);
-                        $code0_log->($init_args, $msg);
-                    };
-                } else {
-                    $code_log = sub {
-                        return unless $code_filter->($lnum, $init_args);
-                        my $msg = $code_formatter->(@_);
-                        $code0_log->($init_args, $msg);
-                    };
+            next unless $logger0;
+            my $logger;
+
+            {
+                if ($_logger_is_null) {
+                    # if logger is a null logger (sub {0}) we don't need to
+                    # format message, layout message, or care about the logger
+                    # being a subroutine/object
+                    $logger = $logger0;
+                    last;
                 }
-            } else {
-                if ($object) {
-                    $code_log = sub {
-                        shift;
-                        my $msg = $code_formatter->(@_);
-                        $code0_log->($init_args, $msg);
-                    };
+
+                if ($formatter) {
+                    if ($layouter) {
+                        if ($object) {
+                            $logger = sub {
+                                shift;
+                                $logger0->($init_args,
+                                           $layouter->(
+                                               $formatter->(@_),
+                                               $init_args, $lnum, $lname));
+                            };
+                        } else {
+                            # not object
+                            $logger = sub {
+                                $logger0->($init_args,
+                                           $layouter->(
+                                               $formatter->(@_),
+                                               $init_args, $lnum, $lname));
+                            };
+                        }
+                    } else {
+                        # no layouter
+                        if ($object) {
+                            $logger = sub {
+                                shift;
+                                $logger0->($init_args, $formatter->(@_));
+                            };
+                        } else {
+                            # not object
+                            $logger = sub {
+                                $logger0->($init_args, $formatter->(@_));
+                            };
+                        }
+                    }
                 } else {
-                    $code_log = sub {
-                        my $msg = $code_formatter->(@_);
-                        $code0_log->($init_args, $msg);
-                    };
+                    # no formatter
+                    if ($object) {
+                        $logger = sub {
+                            shift;
+                            $logger0->($init_args, @_);
+                        };
+                    } else {
+                        # not object
+                        $logger = sub {
+                            $logger0->($init_args, @_);
+                        };
+                    }
                 }
             }
-            push @routines, [$code_log, $rname, $lnum, ($object ? 2:0) | 1];
+            push @routines, [$logger, $rname, $lnum, ($object ? 2:0) | 1];
         }
     }
     {
@@ -357,7 +379,7 @@ Log::ger - A lightweight, flexible logging framework
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
