@@ -1,7 +1,7 @@
 package Log::ger::Format;
 
-our $DATE = '2017-06-26'; # DATE
-our $VERSION = '0.008'; # VERSION
+our $DATE = '2017-06-28'; # DATE
+our $VERSION = '0.009'; # VERSION
 
 use parent qw(Log::ger::Plugin);
 
@@ -20,7 +20,7 @@ Log::ger::Format - Use a format plugin
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -42,12 +42,12 @@ To set for current package only:
 
 =head1 SEE ALSO
 
+L<Log::ger::Layout>
+
 L<Log::ger::Output>
 
 L<Log::ger::Plugin>
 
-L<Log::ger::Filter>
-
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
