@@ -1,7 +1,7 @@
 package Log::ger::Output;
 
-our $DATE = '2017-06-26'; # DATE
-our $VERSION = '0.008'; # VERSION
+our $DATE = '2017-06-28'; # DATE
+our $VERSION = '0.009'; # VERSION
 
 use parent 'Log::ger::Plugin';
 
@@ -20,7 +20,7 @@ Log::ger::Output - Set logging output
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -53,7 +53,7 @@ To set for current package only:
 
 L<Log::ger::Format>
 
-L<Log::ger::Filter>
+L<Log::ger::Layout>
 
 L<Log::ger::Plugin>
 
