@@ -1,7 +1,7 @@
 package Log::ger::Plugin;
 
-our $DATE = '2017-06-26'; # DATE
-our $VERSION = '0.008'; # VERSION
+our $DATE = '2017-06-28'; # DATE
+our $VERSION = '0.009'; # VERSION
 
 use strict;
 use warnings;
@@ -60,7 +60,7 @@ Log::ger::Plugin - Use a plugin
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
@@ -82,11 +82,11 @@ To set for current package only:
 
 =head1 SEE ALSO
 
-L<Log::ger::Output>
-
 L<Log::ger::Format>
 
-L<Log::ger::Filter>
+L<Log::ger::Layout>
+
+L<Log::ger::Output>
 
 =head1 AUTHOR
 
